summaryrefslogtreecommitdiffstats
path: root/cmake
diff options
context:
space:
mode:
authorIvan Solovev <ivan.solovev@qt.io>2022-08-16 12:52:42 +0200
committerIvan Solovev <ivan.solovev@qt.io>2022-08-19 23:52:05 +0200
commit18f0484a0ed9785efe5acb4671695772e5715075 (patch)
tree6045a8468d6a632b652f32394648a094a6fa8254 /cmake
parent3226c82740a7ed73b3d0ca39568d8b1c79500963 (diff)
Rename QT_DEPRECATED_WARNINGS_SINCE -> QT_WARN_DEPRECATED_UP_TO
The new name describes the behavior in a better way. [ChangeLog][Build System] The QT_DEPRECATED_WARNINGS_SINCE macro is renamed to QT_WARN_DEPRECATED_UP_TO. The old name is deprecated, but is still recognized if it is defined during configuration and the new name is not defined. Fixes: QTBUG-104944 Change-Id: I320c033010dfab120db6922598454f95169657f7 Reviewed-by: Edward Welbourne <edward.welbourne@qt.io> Reviewed-by: Alexandru Croitor <alexandru.croitor@qt.io>
Diffstat (limited to 'cmake')
-rw-r--r--cmake/QtFlagHandlingHelpers.cmake8
1 files changed, 4 insertions, 4 deletions
diff --git a/cmake/QtFlagHandlingHelpers.cmake b/cmake/QtFlagHandlingHelpers.cmake
index 34a9bf7e75..fe9e0e072a 100644
--- a/cmake/QtFlagHandlingHelpers.cmake
+++ b/cmake/QtFlagHandlingHelpers.cmake
@@ -191,10 +191,10 @@ function(qt_internal_library_deprecation_level result)
# On other platforms, Qt's own compilation goes needs to compile the Qt 5.0 API
list(APPEND deprecations "QT_DISABLE_DEPRECATED_UP_TO=0x050000")
endif()
- # QT_DEPRECATED_WARNINGS_SINCE controls the upper-bound of deprecation
- # warnings that are emitted. E.g. if it is set to 7.0 then all deprecations
- # during the 6.* lifetime will be warned about in Qt builds.
- list(APPEND deprecations "QT_DEPRECATED_WARNINGS_SINCE=0x070000")
+ # QT_WARN_DEPRECATED_UP_TO controls the upper-bound of deprecation
+ # warnings that are emitted. E.g. if it is set to 0x060500 then all use of
+ # things deprecated in or before 6.5.0 will be warned against.
+ list(APPEND deprecations "QT_WARN_DEPRECATED_UP_TO=0x070000")
set("${result}" "${deprecations}" PARENT_SCOPE)
endfunction()